# Security Policy

## Supported Versions

Use the latest version. This tool is as secure as it can be but please read and evaluate the source code yourself

## Reporting a Vulnerability

Use this section to tell people how to report a vulnerability.

Tell them where to go, how often they can expect to get an update on a
reported vulnerability, what to expect if the vulnerability is accepted or
declined, etc.
